summaryrefslogtreecommitdiffstats
path: root/kviewshell/plugins/djvu/libdjvu/DjVuText.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:56:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:56:05 -0600
commit74c05bbf9d92e43a6cf3799355b5f3598884409e (patch)
tree9371e52e1564e08fd280f28e49981ffeb881b9d2 /kviewshell/plugins/djvu/libdjvu/DjVuText.h
parent45f529de247fc4b3662f6b474abe03fe904306ec (diff)
downloadtdegraphics-74c05bbf9d92e43a6cf3799355b5f3598884409e.tar.gz
tdegraphics-74c05bbf9d92e43a6cf3799355b5f3598884409e.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kviewshell/plugins/djvu/libdjvu/DjVuText.h')
-rw-r--r--kviewshell/plugins/djvu/libdjvu/DjVuText.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kviewshell/plugins/djvu/libdjvu/DjVuText.h b/kviewshell/plugins/djvu/libdjvu/DjVuText.h
index 54708324..b06536c7 100644
--- a/kviewshell/plugins/djvu/libdjvu/DjVuText.h
+++ b/kviewshell/plugins/djvu/libdjvu/DjVuText.h
@@ -133,8 +133,8 @@ public:
int text_start;
/** Length of the zone text in string #textUTF8#. */
int text_length;
- /** List of tqchildren zone. */
- GList<Zone> tqchildren;
+ /** List of children zone. */
+ GList<Zone> children;
/** Appends another subzone inside this zone. The new zone is initialized
with an empty rectangle, empty text, and has the same type as this
zone. */